pub struct VoxelPlainIndex(pub usize);Available on crate feature
chili only.Expand description
Identifier for voxels used internally to get rid of user-defined ones.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for VoxelPlainIndex
impl Clone for VoxelPlainIndex
Sourcefn clone(&self) -> VoxelPlainIndex
fn clone(&self) -> VoxelPlainIndex
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoxelPlainIndex
impl Debug for VoxelPlainIndex
Sourceimpl<'de> Deserialize<'de> for VoxelPlainIndex
impl<'de> Deserialize<'de> for VoxelPlainIndex
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VoxelPlainIndex, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VoxelPlainIndex, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for VoxelPlainIndex
impl Hash for VoxelPlainIndex
Sourceimpl<'py> IntoPyObject<'py> for VoxelPlainIndex
impl<'py> IntoPyObject<'py> for VoxelPlainIndex
Sourcetype Target = VoxelPlainIndex
type Target = VoxelPlainIndex
The Python output type
Sourcetype Output = Bound<'py, <VoxelPlainIndex as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <VoxelPlainIndex as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<VoxelPlainIndex as IntoPyObject<'py>>::Output, <VoxelPlainIndex as IntoPyObject<'py>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<VoxelPlainIndex as IntoPyObject<'py>>::Output, <VoxelPlainIndex as IntoPyObject<'py>>::Error>
Performs the conversion.
Sourceimpl Ord for VoxelPlainIndex
impl Ord for VoxelPlainIndex
Sourcefn cmp(&self, other: &VoxelPlainIndex) -> Ordering
fn cmp(&self, other: &VoxelPlainIndex) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VoxelPlainIndex
impl PartialEq for VoxelPlainIndex
Sourceimpl PartialOrd for VoxelPlainIndex
impl PartialOrd for VoxelPlainIndex
Sourceimpl PyClass for VoxelPlainIndex
impl PyClass for VoxelPlainIndex
Sourceimpl PyTypeInfo for VoxelPlainIndex
impl PyTypeInfo for VoxelPlainIndex
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for VoxelPlainIndex
impl Serialize for VoxelPlainIndex
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for VoxelPlainIndex
impl DerefToPyAny for VoxelPlainIndex
impl Eq for VoxelPlainIndex
impl StructuralPartialEq for VoxelPlainIndex