Struct MultiVoxelContainer

pub struct MultiVoxelContainer<Ind, Pos, Vel, For, Inf, Vox, Dom, Cel, ConcVecExtracellular = (), ConcBoundaryExtracellular = (), ConcVecIntracellular = ()>
where Pos: Serialize + for<'a> Deserialize<'a>, For: Serialize + for<'a> Deserialize<'a>, Vel: Serialize + for<'a> Deserialize<'a>, Cel: Serialize + for<'a> Deserialize<'a>, Dom: Serialize + for<'a> Deserialize<'a>, ConcVecExtracellular: Serialize + for<'a> Deserialize<'a> + 'static, ConcBoundaryExtracellular: Serialize + for<'a> Deserialize<'a>, ConcVecIntracellular: Serialize + for<'a> Deserialize<'a>,
{ /* private fields */ }
Available on crate feature cpu_os_threads only.
Subdomain which consists of multiple Voxels

Implementations

Source

impl<Ind, Pos, Vel, For, Inf, ConcVecExtracellular, ConcBoundaryExtracellular, ConcVecIntracellular, Vox, Dom, Cel> MultiVoxelContainer<Ind, Pos, Vel, For, Inf, Vox, Dom, Cel, ConcVecExtracellular, ConcBoundaryExtracellular, ConcVecIntracellular>
where Ind: Index + Serialize + for<'a> Deserialize<'a>, Vox: Voxel<Ind, Pos, Vel, For>, Dom: Domain<Cel, Ind, Vox>, Pos: Serialize + for<'a> Deserialize<'a>, Vel: Serialize + for<'a> Deserialize<'a>, For: ForceBound + Serialize + for<'a> Deserialize<'a>, Inf: Clone, Cel: Serialize + for<'a> Deserialize<'a> + Send + Sync, ConcVecExtracellular: Serialize + for<'a> Deserialize<'a>, ConcBoundaryExtracellular: Serialize + for<'a> Deserialize<'a>, ConcVecIntracellular: Serialize + for<'a> Deserialize<'a> + Zero,

pub fn run_full_update<ConcGradientExtracellular, ConcTotalExtracellular>( &mut self, dt: &f64, ) -> Result<(), SimulationError>
where Inf: Send + Sync + Debug, Pos: PositionBound, Vel: VelocityBound, ConcVecExtracellular: Concentration, ConcTotalExtracellular: Concentration, ConcVecIntracellular: Mul<f64, Output = ConcVecIntracellular> + Add<ConcVecIntracellular, Output = ConcVecIntracellular> + AddAssign<ConcVecIntracellular>, Cel: Cycle<Cel> + Mechanics<Pos, Vel, For> + Position<Pos> + Velocity<Vel> + Interaction<Pos, Vel, For, Inf> + CellularReactions<ConcVecIntracellular, ConcVecExtracellular> + InteractionExtracellularGradient<Cel, ConcGradientExtracellular> + Volume + Clone, Vox: ExtracellularMechanics<Ind, Pos, ConcVecExtracellular, ConcGradientExtracellular, ConcTotalExtracellular, ConcBoundaryExtracellular> + Volume,

Runs a full update step for all simulation aspects

This function is supposed to be run iteratively multiple times in order to completely run a full simulation.