FixedStepsize

Struct FixedStepsize 

pub struct FixedStepsize<F> { /* private fields */ }
Time stepping with a fixed time length

This time-stepper increments the time variable by the same length.

let t0 = 1.0;
let dt = 0.2;
let partial_save_points = vec![3.0, 5.0, 11.0, 20.0];
let time_stepper = FixedStepsize::from_partial_save_points(t0, dt, partial_save_points).unwrap();

Implementations

Source

impl<F> FixedStepsize<F>

pub fn from_partial_save_steps( t0: F, dt: F, n_steps: u64, save_interval: u64, ) -> Result<Self, TimeError>

Construct the stepper from initial time, increment, number of steps and save interval

pub fn from_partial_save_interval( t0: F, dt: F, t_max: F, save_interval: F, ) -> Result<Self, TimeError>

Similar to Self::from_partial_save_points but specify the time step between every save point together with the integration step.

pub fn from_partial_save_freq( t0: F, dt: F, t_max: F, save_freq: usize, ) -> Result<Self, TimeError>

Similar to Self::from_partial_save_interval but specify a multiple of the time increment instead of a floating point value. This method is preferred over the one previously mentioned.

pub fn from_partial_save_points( t0: F, dt: F, partial_save_points: Vec<F>, ) -> Result<Self, TimeError>

Simple function to construct the stepper from an initial time point, the time increment and the time points at which the simulation should be saved. Notice that these saves do not cover FullSaves but only PartialSaves.